@@ -87,13 +87,6 @@ mapi_profile_load (const char *profname, const char *password)
 	const char *profile = NULL;
 	guint32 debug_log_level = 0;
 
-	/* Initialize libmapi logger*/
-	if (g_getenv ("LIBMAPI_DEBUG")) {
-		debug_log_level = atoi (g_getenv ("MAPI_DEBUG"));
-		SetMAPIDumpData(TRUE);
-		SetMAPIDebugLevel(debug_log_level);
-	}
-
 	/* Initialize libexchangemapi logger*/
 	if (g_getenv ("EXCHANGEMAPI_DEBUG")) {
 		g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, mapi_debug_logger, NULL);
@@ -118,6 +111,13 @@ mapi_profile_load (const char *profname, const char *password)
 		goto cleanup;
 	}
 
+	/* Initialize libmapi logger*/
+	if (g_getenv ("LIBMAPI_DEBUG")) {
+		debug_log_level = atoi (g_getenv ("MAPI_DEBUG"));
+		SetMAPIDumpData(TRUE);
+		SetMAPIDebugLevel(debug_log_level);
+	}
+
 
 	if (profname)
 		profile = profname;
@@ -698,7 +698,7 @@ exchange_mapi_util_get_attachments (mapi_object_t *obj_message, GSList **attach_
 
 		attachment = g_new0 (ExchangeMAPIAttachment, 1);
 		attachment->cValues = properties.cValues; 
-		attachment->lpProps = g_new0 (struct SPropValue, attachment->cValues);
+		attachment->lpProps = g_new0 (struct SPropValue, attachment->cValues + 1);
 		for (z=0; z < properties.cValues; z++) 
 			cast_SPropValue (&properties.lpProps[z], &(attachment->lpProps[z]));
 
@@ -2391,6 +2391,8 @@ exchange_mapi_modify_item (uint32_t olFolder, mapi_id_t fid, mapi_id_t mid,
 	/* Set attachments if any */
 	if (attachments) {
 		exchange_mapi_util_set_attachments (&obj_message, attachments, TRUE);
+	} else {
+		exchange_mapi_util_delete_attachments (&obj_message);
 	}
 
 	/* Set recipients if any */
@@ -3107,7 +3109,7 @@ exchange_mapi_events_init ()
 }
 
 gboolean
-exchange_mapi_events_subscribe (mapi_id_t *obj_id, guint32 options,
+exchange_mapi_events_subscribe (guint32 options,
 				guint16 event_mask, guint32 *connection,
 				mapi_notify_callback_t callback, gpointer data)
 {
@@ -3137,11 +3139,14 @@ exchange_mapi_events_subscribe (mapi_id_t *obj_id, guint32 options,
 }
 
 gboolean
-exchange_mapi_events_unsubscribe (mapi_object_t *obj, guint32 connection)
+exchange_mapi_events_unsubscribe (guint32 connection)
 {
 	enum MAPISTATUS	retval;
 
-	retval = Unsubscribe(mapi_object_get_session(obj), connection);
+	if (!global_mapi_session)
+		return FALSE;
+
+	retval = Unsubscribe (global_mapi_session, connection);
 
 	return (retval == MAPI_E_SUCCESS);
 }
@@ -3155,16 +3160,6 @@ exchange_mapi_events_monitor (struct mapi_notify_continue_callback_data *cb_data
 	return retval;
 }
 
-void
-exchange_mapi_events_monitor_close ()
-{
-	struct mapi_notify_ctx	*notify_ctx;
-	if (global_mapi_session) {
-		notify_ctx = global_mapi_session->notify_ctx;
-		close (notify_ctx->fd);
-	}
-}
-
 /* Shows error message on the console, and, if error_msg is not NULL, then
    sets it to the similar error message as well. */
 static void
